@@ -32,6 +32,7 @@ _VALID_BOARDS = [
     "aodsoc_asoc",
     "aodsoc_aods",
 ]
+_DEFAULT_CLOCK_FILES_CACHE = {}  # Will be populated as needed
 
 
 def get_available_models() -> List[str]:
@@ -137,6 +138,12 @@ def get_configuration(model: str) -> dict:
     try:
         yml_file = REGISTERS_DIR / (model + ".yml")
         result = get_configuration_from_file(yml_file)
+
+        # Cache clock files for use in get_clock*
+        if "clock_file" in result["params"]:
+            _DEFAULT_CLOCK_FILES_CACHE[model] = result["params"]["clock_file"]
+        else:
+            _DEFAULT_CLOCK_FILES_CACHE[model] = None
     except OSError:
         raise
     except ConfigurationFileParsingError:
@@ -238,15 +245,29 @@ def get_clock_file(model: str) -> Path:
     if model not in _VALID_BOARDS:
         raise InvalidBoardModelError(f'Invalid board model "{model}"')
 
-    # (wastefully) parse the params file to get the clock file name
-    config = get_configuration(model)
+    if model not in _DEFAULT_CLOCK_FILES_CACHE:
+        # parse the params file to get the clock file name
+        config = get_configuration(model)
+        if "clock_file" in config["params"]:
+            clock_file = config["params"]["clock_file"]
+        else:
+            clock_file = None
+    else:
+        clock_file = _DEFAULT_CLOCK_FILES_CACHE[model]
 
-    if "clock_file" in config["params"]:
-        return CLOCKS_DIR / config["params"]["clock_file"]
+    if clock_file is not None:
+        return CLOCKS_DIR / clock_file
     else:
         return None
 
 
+def clear_config_caches():
+    """Clears caches used to grab chip and board data quickly.
+    """
+    _DEFAULT_CLOCK_FILES_CACHE.clear()
+    _constructors.helpers._default_chip_config_cache.clear()
+
+
 def _load_yaml_file(filename) -> dict:
     """Loads a yaml file into a dict.
 
