@@ -15,6 +15,7 @@ REGISTERS_DIR = CONFIGS_DIR / "registers"
 CLOCKS_DIR = CONFIGS_DIR / "clocks"
 CHIPS_DIR = CONFIGS_DIR / "chips"
 
+_default_chip_config_cache = {}
 
 def default_chip_config(chip_name: str) -> dict:
     """Retrieve the default chip config for a chip.
@@ -30,10 +31,14 @@ def default_chip_config(chip_name: str) -> dict:
         OSError: if the config file cannot be read
         yaml.YAMLError: if the config file is invalid YAML
     """
+    if chip_name in _default_chip_config_cache:
+        return _default_chip_config_cache[chip_name]
     yml_file = CHIPS_DIR / (chip_name + ".yml")
     try:
         with open(yml_file, "r") as f:
-            return yaml.safe_load(f)
+            out = yaml.safe_load(f)
+            _default_chip_config_cache[chip_name] = out
+            return out
     except (FileNotFoundError, OSError):
         raise
     except yaml.YAMLError:
